package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseQualityInspectionItemMapper;
import com.aucma.base.domain.BaseQualityInspectionItem;
import com.aucma.base.service.IBaseQualityInspectionItemService;

/**
 * 质检项信息维护Service业务层处理
 *
 * @author Yinq
 * @date 2023-10-16
 */
@Service
public class BaseQualityInspectionItemServiceImpl implements IBaseQualityInspectionItemService
{
    @Autowired
    private BaseQualityInspectionItemMapper baseQualityInspectionItemMapper;

    /**
     * 查询质检项信息维护
     *
     * @param objId 质检项信息维护主键
     * @return 质检项信息维护
     */
    @Override
    public BaseQualityInspectionItem selectBaseQualityInspectionItemByObjId(Long objId)
    {
        return baseQualityInspectionItemMapper.selectBaseQualityInspectionItemByObjId(objId);
    }

    /**
     * 查询所有父级以及名称
     * */
    @Override
    public List<BaseQualityInspectionItem> selectBaseQualityInspectionItemParent() {
        return baseQualityInspectionItemMapper.selectBaseQualityInspectionItemParent();
    }

    /**
     * 查询质检项信息维护列表
     *
     * @param baseQualityInspectionItem 质检项信息维护
     * @return 质检项信息维护
     */
    @Override
    public List<BaseQualityInspectionItem> selectBaseQualityInspectionItemList(BaseQualityInspectionItem baseQualityInspectionItem)
    {
        return baseQualityInspectionItemMapper.selectBaseQualityInspectionItemList(baseQualityInspectionItem);
    }

    /**
     * 新增质检项信息维护
     *
     * @param baseQualityInspectionItem 质检项信息维护
     * @return 结果
     */
    @Override
    public int insertBaseQualityInspectionItem(BaseQualityInspectionItem baseQualityInspectionItem)
    {
        return baseQualityInspectionItemMapper.insertBaseQualityInspectionItem(baseQualityInspectionItem);
    }

    /**
     * 修改质检项信息维护
     *
     * @param baseQualityInspectionItem 质检项信息维护
     * @return 结果
     */
    @Override
    public int updateBaseQualityInspectionItem(BaseQualityInspectionItem baseQualityInspectionItem)
    {
        return baseQualityInspectionItemMapper.updateBaseQualityInspectionItem(baseQualityInspectionItem);
    }

    /**
     * 批量删除质检项信息维护
     *
     * @param objIds 需要删除的质检项信息维护主键
     * @return 结果
     */
    @Override
    public int deleteBaseQualityInspectionItemByObjIds(Long[] objIds)
    {
        return baseQualityInspectionItemMapper.deleteBaseQualityInspectionItemByObjIds(objIds);
    }

    /**
     * 删除质检项信息维护信息
     *
     * @param objId 质检项信息维护主键
     * @return 结果
     */
    @Override
    public int deleteBaseQualityInspectionItemByObjId(Long objId)
    {
        return baseQualityInspectionItemMapper.deleteBaseQualityInspectionItemByObjId(objId);
    }
}
